Statifier.Actions.RaiseAction (statifier v1.9.0)

Represents a <raise> action in SCXML.

The <raise> element generates an internal event that is immediately placed in the interpreter's event queue for processing in the current macrostep.

Summary

Functions

Executes the raise action by creating an internal event and adding it to the state chart's event queue.

Types

t()

@type t() :: %Statifier.Actions.RaiseAction{
  event: String.t() | nil,
  source_location: map() | nil
}

Functions

execute(state_chart, raise_action)

Executes the raise action by creating an internal event and adding it to the state chart's event queue.