Statifier.Actions.SendParam (statifier v1.5.0)
View SourceRepresents a <param> child element of <send> in SCXML.
The <param> element provides key-value pairs to include with the event data.
Must specify either expr or location, but not both.
Represents a <param> child element of <send> in SCXML.
The <param> element provides key-value pairs to include with the event data.
Must specify either expr or location, but not both.