Statifier.Validator.ReachabilityAnalyzer (statifier v1.9.0)
View SourceAnalyzes state reachability in SCXML documents.
Performs graph traversal to identify unreachable states and warn about them.
Summary
Functions
Find all states reachable from a given starting state.
Validate that all states except the initial state are reachable.
Functions
@spec find_reachable_states(String.t(), Statifier.Document.t(), MapSet.t(String.t())) :: MapSet.t(String.t())
Find all states reachable from a given starting state.
@spec validate_reachability( Statifier.Validator.validation_result(), Statifier.Document.t() ) :: Statifier.Validator.validation_result()
Validate that all states except the initial state are reachable.