Statifier.Validator.TransitionValidator (statifier v1.5.0)

Validates transition-related constraints in SCXML documents.

Handles transition target validation and transition structure validation.

Summary

Functions

Validate that all transition targets exist in the document.

Functions

validate_transition_targets(result, document)

Validate that all transition targets exist in the document.