Statifier.Actions.LogAction (statifier v1.9.0)
View SourceRepresents a <log> element in SCXML.
The <log> element is used to generate logging output. It has two optional attributes:
label: A string that identifies the source of the log entryexpr: An expression to evaluate and include in the log output
Per the SCXML specification, if neither label nor expr are provided, the element has no effect.
Summary
Functions
Executes the log action by evaluating the expression and logging the result.
Creates a new log action from parsed attributes.
Types
Functions
@spec execute(Statifier.StateChart.t(), t()) :: Statifier.StateChart.t()
Executes the log action by evaluating the expression and logging the result.
Creates a new log action from parsed attributes.