Statifier.Actions.RaiseAction (statifier v1.9.0)
View SourceRepresents a <raise> action in SCXML.
The <raise> element generates an internal event that is immediately placed in the interpreter's event queue for processing in the current macrostep.
Summary
Functions
Executes the raise action by creating an internal event and adding it to the state chart's event queue.
Types
Functions
@spec execute(Statifier.StateChart.t(), t()) :: Statifier.StateChart.t()
Executes the raise action by creating an internal event and adding it to the state chart's event queue.