Statifier.Actions.SendAction (statifier v1.9.0)
View SourceRepresents a <send> element action in SCXML.
The <send> element provides SCXML state machines with the ability to:
- Send events to internal or external destinations
- Schedule delayed event delivery
- Include structured data with events
- Enable inter-session communication
- Interface with external systems via Event I/O Processors
Summary
Functions
Executes the send action by creating an event and routing it to the appropriate destination. For Phase 1, only supports immediate internal sends.
Types
@type t() :: %Statifier.Actions.SendAction{ compiled_delay_expr: term() | nil, compiled_event_expr: term() | nil, compiled_target_expr: term() | nil, compiled_type_expr: term() | nil, content: Statifier.Actions.SendContent.t() | nil, delay: String.t() | nil, delay_expr: String.t() | nil, event: String.t() | nil, event_expr: String.t() | nil, id: String.t() | nil, id_location: String.t() | nil, namelist: String.t() | nil, params: [Statifier.Actions.Param.t()], source_location: map() | nil, target: String.t() | nil, target_expr: String.t() | nil, type: String.t() | nil, type_expr: String.t() | nil }
Functions
@spec execute(Statifier.StateChart.t(), t()) :: Statifier.StateChart.t()
Executes the send action by creating an event and routing it to the appropriate destination. For Phase 1, only supports immediate internal sends.